==> v1.0.0.tar.gz: platomix-gmetry-bi/platomix-gmetry-bi-api/src/main/java/org/springblade/visual/service/VisualDataPermissionService.java <==
/**
 * 
 */
package org.springblade.visual.service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Optional;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.tool.utils.CollectionUtil;
import org.springblade.system.client.DataPermClient;
import org.springblade.visual.dto.VisualDataPermissionDoo;
import org.springblade.visual.dto.VisualDataPermissionDto;
import org.springblade.visual.entity.VisualData;
import org.springblade.visual.entity.VisualDataPermission;
import org.springblade.visual.mapper.VisualDataPermissionMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

/**
 * @author wookvn
 *
 */
@Service
public class VisualDataPermissionService extends ServiceImpl<VisualDataPermissionMapper, VisualDataPermission> {

	@Autowired
	private DataPermClient dataPermClient;
	
	@Autowired
	private VisualDataService visualDataService;
	
	/**
	 * 检查用户是否有大屏的访问权限
	 * @param visualDataId
	 * @param visualCreateUserId
	 * @param bladeUser
	 * @return
	 */
	public boolean checkVisualDataForUser(Integer visualDataId, Long visualCreateUserId, BladeUser bladeUser) {
		//检查4个方面：
		//1.当前用户是否创建人
		//2.是否公开
		//3.是否超级权限组
		//4.当前用户是否拥有权限
		return  visualCreateUserId.longValue() == bladeUser.getUserId()
				|| visualDataService.count(Wrappers.<VisualData>lambdaQuery().eq(VisualData::getId, visualDataId).eq(VisualData::getPublicStatus, 1)) > 0
				|| Optional.<Boolean>ofNullable(dataPermClient.checkSuperPermission(bladeUser.getUserId())).orElse(false)
				|| baseMapper.checkVisualForUser(visualDataId, bladeUser.getUserId()) > 0;
	}
	
	/**
	 * 权限组管理入口 
	 * 说明：一个权限组和多个大屏的设置
	 * @param visualDataPermDto
	 * @return
	 */
	@Transactional
	public boolean doSaveOrUpdate(VisualDataPermissionDto visualDataPermDto, BladeUser bladeUser) {
		//通过关联删除，删除大屏分类ID的数据
		baseMapper.deleteByClassifyIdAndPermId(visualDataPermDto.getVisualClassifyId(), visualDataPermDto.getDataPermId());
		//2.再添加
		if(CollectionUtil.isNotEmpty(visualDataPermDto.getVisualIdList())) {
			//更新公开状态为0[否则权限组不生效]
			visualDataService.update(Wrappers.<VisualData>lambdaUpdate().set(VisualData::getPublicStatus, 0).in(VisualData::getId, visualDataPermDto.getVisualIdList()));
			List<VisualDataPermission> dataList = new ArrayList<>(visualDataPermDto.getVisualIdList().size());
			visualDataPermDto.getVisualIdList().forEach(t -> {
				VisualDataPermission entity = new VisualDataPermission();
				entity.setCreateBy(bladeUser.getNickName());
				entity.setCreateTime(new Date());
				entity.setCreateUserId(bladeUser.getUserId());
				entity.setDataPermId(visualDataPermDto.getDataPermId());
				entity.setVisualId(t);
				dataList.add(entity);
			});
			saveBatch(dataList);
		}
		return true;
	}
	
	/**
	 * 大屏列表的权限组管理入口
	 * @param visualDataPermDoo
	 * @param bladeUser
	 * @return
	 */
	@Transactional
	public boolean doPerform(VisualDataPermissionDoo visualDataPermDoo, BladeUser bladeUser) {
		//1.根据大屏ID删除所属权限组
		baseMapper.delete(Wrappers.<VisualDataPermission>lambdaQuery().eq(VisualDataPermission::getVisualId, visualDataPermDoo.getVisualId()));
		//2.批量添加权限组
		if(CollectionUtil.isNotEmpty(visualDataPermDoo.getDataPermIdList())) {
			visualDataService.update(Wrappers.<VisualData>lambdaUpdate().set(VisualData::getPublicStatus, 0).eq(VisualData::getId, visualDataPermDoo.getVisualId()));
			List<VisualDataPermission> dataList = new ArrayList<>(visualDataPermDoo.getDataPermIdList().size());
			visualDataPermDoo.getDataPermIdList().forEach(dataPermId -> {
				VisualDataPermission entity = new VisualDataPermission();
				entity.setCreateBy(bladeUser.getNickName());
				entity.setCreateTime(new Date());
				entity.setCreateUserId(bladeUser.getUserId());
				entity.setDataPermId(dataPermId);
				entity.setVisualId(visualDataPermDoo.getVisualId());
				dataList.add(entity);
			});
			saveBatch(dataList);
		}
		return true;
	}
	
	/**
	 * 
	 * @param dataPermId
	 * @param classifyId
	 * @return
	 */
	public List<Integer> listVisualId(Integer dataPermId, Integer classifyId){
		return baseMapper.selectVisualIdList(dataPermId, classifyId);
	}
	
	public List<JSONObject> listDataPerm(Integer visualId){
		return baseMapper.selectDataPermList(visualId);
	}
}

==> v3.4.1.tar.gz: platomix-gmetry-bi/platomix-gmetry-bi-api/src/main/java/org/springblade/visual/service/VisualDataPermissionService.java <==
/**
 * 
 */
package org.springblade.visual.service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Optional;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.tool.utils.CollectionUtil;
import org.springblade.system.client.DataPermClient;
import org.springblade.visual.dto.VisualDataPermissionDoo;
import org.springblade.visual.dto.VisualDataPermissionDto;
import org.springblade.visual.entity.VisualData;
import org.springblade.visual.entity.VisualDataPermission;
import org.springblade.visual.mapper.VisualDataPermissionMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

/**
 * @author wookvn
 *
 */
@Service
public class VisualDataPermissionService extends ServiceImpl<VisualDataPermissionMapper, VisualDataPermission> {

	@Autowired
	private DataPermClient dataPermClient;
	
	@Autowired
	private VisualDataService visualDataService;
	
	/**
	 * 检查用户是否有大屏的访问权限
	 * @param visualDataId
	 * @param visualCreateUserId
	 * @param bladeUser
	 * @return
	 */
	public boolean checkVisualDataForUser(Integer visualDataId, Long visualCreateUserId, BladeUser bladeUser) {
		//检查4个方面：
		//1.当前用户是否创建人
		//2.是否公开
		//3.是否超级权限组
		//4.当前用户是否拥有权限
		return  visualCreateUserId.longValue() == bladeUser.getUserId()
				|| visualDataService.count(Wrappers.<VisualData>lambdaQuery().eq(VisualData::getId, visualDataId).eq(VisualData::getPublicStatus, 1)) > 0
				|| Optional.<Boolean>ofNullable(dataPermClient.checkSuperPermission(bladeUser.getUserId())).orElse(false)
				|| baseMapper.checkVisualForUser(visualDataId, bladeUser.getUserId()) > 0;
	}
	
	/**
	 * 权限组管理入口 
	 * 说明：一个权限组和多个大屏的设置
	 * @param visualDataPermDto
	 * @return
	 */
	@Transactional
	public boolean doSaveOrUpdate(VisualDataPermissionDto visualDataPermDto, BladeUser bladeUser) {
		//通过关联删除，删除大屏分类ID的数据
		baseMapper.deleteByClassifyIdAndPermId(visualDataPermDto.getVisualClassifyId(), visualDataPermDto.getDataPermId());
		//2.再添加
		if(CollectionUtil.isNotEmpty(visualDataPermDto.getVisualIdList())) {
			//更新公开状态为0[否则权限组不生效]
			visualDataService.update(Wrappers.<VisualData>lambdaUpdate().set(VisualData::getPublicStatus, 0).in(VisualData::getId, visualDataPermDto.getVisualIdList()));
			List<VisualDataPermission> dataList = new ArrayList<>(visualDataPermDto.getVisualIdList().size());
			visualDataPermDto.getVisualIdList().forEach(t -> {
				VisualDataPermission entity = new VisualDataPermission();
				entity.setCreateBy(bladeUser.getNickName());
				entity.setCreateTime(new Date());
				entity.setCreateUserId(bladeUser.getUserId());
				entity.setDataPermId(visualDataPermDto.getDataPermId());
				entity.setVisualId(t);
				dataList.add(entity);
			});
			saveBatch(dataList);
		}
		return true;
	}
	
	/**
	 * 大屏列表的权限组管理入口
	 * @param visualDataPermDoo
	 * @param bladeUser
	 * @return
	 */
	@Transactional
	public boolean doPerform(VisualDataPermissionDoo visualDataPermDoo, BladeUser bladeUser) {
		//1.根据大屏ID删除所属权限组
		baseMapper.delete(Wrappers.<VisualDataPermission>lambdaQuery().eq(VisualDataPermission::getVisualId, visualDataPermDoo.getVisualId()));
		if(visualDataPermDoo.getPublicStatus() != null) {
			visualDataService.update(Wrappers.<VisualData>lambdaUpdate().set(VisualData::getPublicStatus, visualDataPermDoo.getPublicStatus()).eq(VisualData::getId, visualDataPermDoo.getVisualId()));
		}
		//2.批量添加权限组
		if(CollectionUtil.isNotEmpty(visualDataPermDoo.getDataPermIdList())) {
			List<VisualDataPermission> dataList = new ArrayList<>(visualDataPermDoo.getDataPermIdList().size());
			visualDataPermDoo.getDataPermIdList().forEach(dataPermId -> {
				VisualDataPermission entity = new VisualDataPermission();
				entity.setCreateBy(bladeUser.getNickName());
				entity.setCreateTime(new Date());
				entity.setCreateUserId(bladeUser.getUserId());
				entity.setDataPermId(dataPermId);
				entity.setVisualId(visualDataPermDoo.getVisualId());
				dataList.add(entity);
			});
			saveBatch(dataList);
		}
		return true;
	}
	
	/**
	 * 
	 * @param dataPermId
	 * @param classifyId
	 * @return
	 */
	public List<Integer> listVisualId(Integer dataPermId, Integer classifyId){
		return baseMapper.selectVisualIdList(dataPermId, classifyId);
	}
	
	public List<JSONObject> listDataPerm(Integer visualId){
		return baseMapper.selectDataPermList(visualId);
	}
}
